cheesecake

Package cheesecake |
[hide private]
[frames] | no frames]

## Package cheesecake
source code

Submodules | [hide private]
cheesecake.ast_pp cheesecake.cheesecake_index: Cheesecake: How tasty is your code? cheesecake.codeparser cheesecake.logger cheesecake.model: Code borrowed from Michael Hudson's docextractor package with the author's permission. cheesecake.subprocess: subprocess - Subprocesses with accessible I/O streams This module allows you to spawn processes, connect to their input/output/error pipes, and obtain their return codes. cheesecake.util: Utility functions for Cheesecake project.

Variables | [hide private]
__version__ |

Variables Details | [hide private]

    ### __version__ Value:
        '0.6'